==> hadoop-common-2.10.0-javadoc.jar: native/CMakeFiles/test_bulk_crc32.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util/bulk_crc32.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/org/apache/hadoop/util/bulk_crc32.c.o"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util/bulk_crc32_x86.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/org/apache/hadoop/util/bulk_crc32_x86.c.o"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/test/org/apache/hadoop/util/test_bulk_crc32.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/test/org/apache/hadoop/util/test_bulk_crc32.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "javah"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src"
  "/build/source/hadoop-common-project/hadoop-common/src"
  "/build/source/hadoop-common-project/hadoop-common/src/src"
  "."
  "/usr/lib/jvm/java-1.7.0-openjdk-amd64/include"
  "/usr/lib/jvm/java-1.7.0-openjdk-amd64/include/linux"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util"
  )
set(CMAKE_CXX_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_Fortran_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})
set(CMAKE_ASM_TARGET_INCLUDE_PATH ${CMAKE_C_TARGET_INCLUDE_PATH})

==> hadoop-common-2.10.2-javadoc.jar: native/CMakeFiles/test_bulk_crc32.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util/bulk_crc32.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/org/apache/hadoop/util/bulk_crc32.c.o"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util/bulk_crc32_x86.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/org/apache/hadoop/util/bulk_crc32_x86.c.o"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/test/org/apache/hadoop/util/test_bulk_crc32.c" "/build/source/hadoop-common-project/hadoop-common/target/native/CMakeFiles/test_bulk_crc32.dir/main/native/src/test/org/apache/hadoop/util/test_bulk_crc32.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "javah"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src"
  "/build/source/hadoop-common-project/hadoop-common/src"
  "/build/source/hadoop-common-project/hadoop-common/src/src"
  "."
  "/usr/lib/jvm/zulu-7-amd64/include"
  "/usr/lib/jvm/zulu-7-amd64/include/linux"
  "/build/source/hadoop-common-project/hadoop-common/src/main/native/src/org/apache/hadoop/util"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
